==> hazelcast-all-3.1.6-sources.jar: com/hazelcast/management/operation/ThreadDumpOperation.java <==
/*
 * Copyright (c) 2008-2013, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.management.operation;

import com.hazelcast.management.ThreadDumpGenerator;
import com.hazelcast.nio.ObjectDataInput;
import com.hazelcast.nio.ObjectDataOutput;
import com.hazelcast.spi.Operation;

import java.io.IOException;

/**
 * User: sancar
 * Date: 3/27/13
 * Time: 11:09 AM
 */
public class ThreadDumpOperation extends Operation {

    private boolean isDeadlock;
    private String result;

    public ThreadDumpOperation() {
        this(false);
    }

    public ThreadDumpOperation(boolean deadlock) {
        super();
        this.isDeadlock = deadlock;
    }

    public void beforeRun() throws Exception {
    }

    public void run() throws Exception {
        result = isDeadlock ? ThreadDumpGenerator.dumpDeadlocks() : ThreadDumpGenerator.dumpAllThreads();
    }

    public void afterRun() throws Exception {
    }

    public boolean returnsResponse() {
        return true;
    }

    public Object getResponse() {
        return result;
    }

    protected void writeInternal(ObjectDataOutput out) throws IOException {
        out.writeBoolean(isDeadlock);
    }

    protected void readInternal(ObjectDataInput in) throws IOException {
        isDeadlock = in.readBoolean();
    }
}

==> hazelcast-all-3.2-sources.jar: com/hazelcast/management/operation/ThreadDumpOperation.java <==
/*
 * Copyright (c) 2008-2013, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.management.operation;

import com.hazelcast.management.ThreadDumpGenerator;
import com.hazelcast.nio.ObjectDataInput;
import com.hazelcast.nio.ObjectDataOutput;
import com.hazelcast.spi.Operation;

import java.io.IOException;

public class ThreadDumpOperation extends Operation {

    private boolean dumpDeadlocks;
    private String result;

    public ThreadDumpOperation() {
        this(false);
    }

    public ThreadDumpOperation(boolean dumpDeadlocks) {
        this.dumpDeadlocks = dumpDeadlocks;
    }

    public void beforeRun() throws Exception {
    }

    public void run() throws Exception {
        result = dumpDeadlocks ? ThreadDumpGenerator.dumpDeadlocks() : ThreadDumpGenerator.dumpAllThreads();
    }

    public void afterRun() throws Exception {
    }

    public boolean returnsResponse() {
        return true;
    }

    public Object getResponse() {
        return result;
    }

    protected void writeInternal(ObjectDataOutput out) throws IOException {
        out.writeBoolean(dumpDeadlocks);
    }

    protected void readInternal(ObjectDataInput in) throws IOException {
        dumpDeadlocks = in.readBoolean();
    }
}
